@@ -13,7 +13,6 @@
 #include <ctype.h>
 #include <assert.h>
 
-#include "config.h"
 #include "options.h"
 #include "uae.h"
 #include "gensound.h"
@@ -35,7 +34,7 @@ static unsigned int total_skipped = 0;
 
 /* Mouse and joystick emulation */
 
-int buttonstate[3];
+static int buttonstate[3];
 static int mouse_x, mouse_y;
 int joy0button, joy1button;
 unsigned int joy0dir, joy1dir;
@@ -46,8 +45,6 @@ unsigned long int cycles, nextevent, is_lastline;
 static int rpt_did_reset;
 struct ev eventtab[ev_max];
 
-frame_time_t vsynctime, vsyncmintime;
-
 static int vpos;
 static uae_u16 lof;
 static int next_lineno;
@@ -76,7 +73,6 @@ int maxvpos = MAXVPOS_PAL;
 int minfirstline = MINFIRSTLINE_PAL;
 int vblank_endline = VBLANK_ENDLINE_PAL;
 int vblank_hz = VBLANK_HZ_PAL;
-unsigned long syncbase;
 static int fmode;
 static unsigned int beamcon0, new_beamcon0;
 static int ntscmode = 0;
@@ -121,12 +117,12 @@ enum diw_states
 };
 
 static int plffirstline, plflastline, plfstrt, plfstop, plflinelen;
-int diwfirstword, diwlastword;
+static int diwfirstword, diwlastword;
 static enum diw_states diwstate, hdiwstate;
 
 /* Sprite collisions */
-uae_u16 clxdat, clxcon;
-int clx_sprmask;
+static uae_u16 clxdat, clxcon;
+static int clx_sprmask;
 
 enum copper_states {
     COP_stop,
@@ -158,17 +154,18 @@ int dskdmaen; /* used in cia.c */
  */
 
 /* Used also by bebox.cpp */
-unsigned long int msecs = 0, frametime = 0, lastframetime = 0, timeframes = 0;
+static unsigned long int msecs = 0, lastframetime = 0;
+unsigned long int frametime = 0, timeframes = 0;
 static unsigned long int seconds_base;
 int bogusframe;
 
 
 static int current_change_set;
 
-struct sprite_draw *curr_sprite_positions, *prev_sprite_positions;
-struct color_change *curr_color_changes, *prev_color_changes;
-struct draw_info *curr_drawinfo, *prev_drawinfo;
-struct color_entry *curr_color_tables, *prev_color_tables;
+static struct sprite_draw *curr_sprite_positions, *prev_sprite_positions;
+static struct color_change *curr_color_changes, *prev_color_changes;
+static struct draw_info *curr_drawinfo, *prev_drawinfo;
+static struct color_entry *curr_color_tables, *prev_color_tables;
 
 static int next_color_change, next_sprite_draw, next_delay_change;
 static int next_color_entry, remembered_color_entry;
@@ -207,11 +204,10 @@ void reset_frame_rate_hack (void)
 
     rpt_did_reset = 1;
     is_lastline = 0;
-    vsyncmintime = read_processor_time() + vsynctime;
     write_log ("Resetting frame rate hack\n");
 }
 
-static __inline__ void prepare_copper (void)
+static inline void prepare_copper (void)
 {
     if (cop_state.vpos > vpos
 	|| cop_state.state == COP_stop)
@@ -236,7 +232,7 @@ void check_prefs_changed_custom (void)
 	
 }
 
-static __inline__ void setclr (uae_u16 *p, uae_u16 val)
+static inline void setclr (uae_u16 *p, uae_u16 val)
 {
     if (val & 0x8000)
 	*p |= val & 0x7FFF;
@@ -244,7 +240,7 @@ static __inline__ void setclr (uae_u16 *p, uae_u16 val)
 	*p &= ~val;
 }
 
-__inline__ int current_hpos (void)
+inline int current_hpos (void)
 {
     return cycles - eventtab[ev_hsync].oldcycles;
 }
@@ -274,8 +270,6 @@ static void init_hz (void)
 	vblank_endline = VBLANK_ENDLINE_NTSC;
 	vblank_hz = VBLANK_HZ_NTSC;
     }
-    vsynctime = syncbase / vblank_hz;
-
     // write_log ("Using %s timing\n", isntsc ? "NTSC" : "PAL");
 }
 
@@ -293,9 +287,9 @@ static int lastspr0x,lastspr0y,lastdiffx,lastdiffy,spr0pos,spr0ctl;
 static int mstepx,mstepy,xoffs=defxoffs,yoffs=defyoffs;
 static int sprvbfl;
 
-int lastmx, lastmy;
-int newmousecounters;
-int ievent_alive = 0;
+static int lastmx, lastmy;
+static int newmousecounters;
+static int ievent_alive = 0;
 
 static int timehack_alive = 0;
 
@@ -320,7 +314,7 @@ static uae_u32 timehack_helper (void)
  /*
   * register functions
   */
-static __inline__ uae_u16 DENISEID (void)
+static inline uae_u16 DENISEID (void)
 {
     if (currprefs.chipset_mask & CSMASK_AGA)
 	return 0xF8;
@@ -328,11 +322,11 @@ static __inline__ uae_u16 DENISEID (void)
 	return 0xFC;
     return 0xFFFF;
 }
-static __inline__ uae_u16 DMACONR (void)
+static inline uae_u16 DMACONR (void)
 {
     return (dmacon | 0 | 0x2000);
 }
-static __inline__ uae_u16 INTENAR (void)
+static inline uae_u16 INTENAR (void)
 {
     return intena;
 }
@@ -340,11 +334,11 @@ uae_u16 INTREQR (void)
 {
     return intreq | (currprefs.use_serial ? 0x0001 : 0);
 }
-static __inline__ uae_u16 ADKCONR (void)
+static inline uae_u16 ADKCONR (void)
 {
     return adkcon;
 }
-static __inline__ uae_u16 VPOSR (void)
+static inline uae_u16 VPOSR (void)
 {
     unsigned int csbit = ntscmode ? 0x1000 : 0;
     csbit |= (currprefs.chipset_mask & CSMASK_AGA) ? 0x2300 : 0;
@@ -362,15 +356,15 @@ static void VPOSW (uae_u16 v)
      */
 }
 
-static __inline__ uae_u16 VHPOSR (void)
+static inline uae_u16 VHPOSR (void)
 {
     return (vpos << 8) | current_hpos();
 }
 
-static __inline__ void COP1LCH (uae_u16 v) { cop1lc = (cop1lc & 0xffff) | ((uae_u32)v << 16); }
-static __inline__ void COP1LCL (uae_u16 v) { cop1lc = (cop1lc & ~0xffff) | (v & 0xfffe); }
-static __inline__ void COP2LCH (uae_u16 v) { cop2lc = (cop2lc & 0xffff) | ((uae_u32)v << 16); }
-static __inline__ void COP2LCL (uae_u16 v) { cop2lc = (cop2lc & ~0xffff) | (v & 0xfffe); }
+static inline void COP1LCH (uae_u16 v) { cop1lc = (cop1lc & 0xffff) | ((uae_u32)v << 16); }
+static inline void COP1LCL (uae_u16 v) { cop1lc = (cop1lc & ~0xffff) | (v & 0xfffe); }
+static inline void COP2LCH (uae_u16 v) { cop2lc = (cop2lc & 0xffff) | ((uae_u32)v << 16); }
+static inline void COP2LCL (uae_u16 v) { cop2lc = (cop2lc & ~0xffff) | (v & 0xfffe); }
 
 static void COPJMP1 (uae_u16 a)
 {
@@ -402,18 +396,16 @@ static void COPJMP2 (uae_u16 a)
     events_schedule ();
 }
 
-static __inline__ void COPCON (uae_u16 a)
+static inline void COPCON (uae_u16 a)
 {
     copcon = a;
 }
 
 static void DMACON (uae_u16 v)
 {
-    int i, need_resched = 0;
+    int i;
     uae_u16 oldcon = dmacon;
 
-    uade_aud_dma(v & 0x820f);
-
     setclr(&dmacon,v); dmacon &= 0x1FFF;
     /* ??? post_decide_line (); */
 
@@ -430,8 +422,8 @@ static void DMACON (uae_u16 v)
 	prepare_copper ();
 	if (eventtab[ev_copper].evtime == cycles && eventtab[ev_copper].active)
 	    abort ();
-	need_resched = 1;
     }
+
     update_audio ();
 
     for (i = 0; i < 4; i++) {
@@ -442,6 +434,7 @@ static void DMACON (uae_u16 v)
 	    if (cdp->state == 0) {
 		cdp->state = 1;
 		cdp->pt = cdp->lc;
+		cdp->ptend = cdp->lc + 2 * (cdp->len ? cdp->len : 65536);
 		cdp->wper = cdp->per;
 		cdp->wlen = cdp->len;
 		cdp->data_written = 2;
@@ -450,19 +443,17 @@ static void DMACON (uae_u16 v)
 	} else {
 	    if (cdp->state == 1 || cdp->state == 5) {
 		cdp->state = 0;
-		cdp->last_sample = 0;
 		cdp->current_sample = 0;
 	    }
 	}
     }
 
-    if (need_resched)
-	events_schedule();
+    events_schedule();
 }
 
 /*static int trace_intena = 0;*/
 
-static __inline__ void INTENA (uae_u16 v)
+static inline void INTENA (uae_u16 v)
 {
 /*    if (trace_intena)
 	fprintf (stderr, "INTENA: %04x\n", v);*/
@@ -503,16 +494,16 @@ static void BPLPTL (int hpos, uae_u16 v, int num)
 static void BPLCON0 (int hpos, uae_u16 v)
 {
 }
-static __inline__ void BPLCON1 (int hpos, uae_u16 v)
+static inline void BPLCON1 (int hpos, uae_u16 v)
 {
 }
-static __inline__ void BPLCON2 (int hpos, uae_u16 v)
+static inline void BPLCON2 (int hpos, uae_u16 v)
 {
 }
-static __inline__ void BPLCON3 (int hpos, uae_u16 v)
+static inline void BPLCON3 (int hpos, uae_u16 v)
 {
 }
-static __inline__ void BPLCON4 (int hpos, uae_u16 v)
+static inline void BPLCON4 (int hpos, uae_u16 v)
 {
 }
 
@@ -525,14 +516,14 @@ static void BPL2MOD (int hpos, uae_u16 v)
 }
 
 /* We could do as well without those... */
-static __inline__ void BPL1DAT (uae_u16 v) {}
-static __inline__ void BPL2DAT (uae_u16 v) {}
-static __inline__ void BPL3DAT (uae_u16 v) {}
-static __inline__ void BPL4DAT (uae_u16 v) {}
-static __inline__ void BPL5DAT (uae_u16 v) {}
-static __inline__ void BPL6DAT (uae_u16 v) {}
-static __inline__ void BPL7DAT (uae_u16 v) {}
-static __inline__ void BPL8DAT (uae_u16 v) {}
+static inline void BPL1DAT (uae_u16 v) {}
+static inline void BPL2DAT (uae_u16 v) {}
+static inline void BPL3DAT (uae_u16 v) {}
+static inline void BPL4DAT (uae_u16 v) {}
+static inline void BPL5DAT (uae_u16 v) {}
+static inline void BPL6DAT (uae_u16 v) {}
+static inline void BPL7DAT (uae_u16 v) {}
+static inline void BPL8DAT (uae_u16 v) {}
 
 static void DIWSTRT (int hpos, uae_u16 v)
 {
@@ -608,16 +599,16 @@ static void BLTSIZH (uae_u16 v)
   fprintf(stderr,"blitter stroken in BLTSIZE (custom.c)...\n");
 }
 
-static __inline__ void SPRxCTL_1 (uae_u16 v, int num)
+static inline void SPRxCTL_1 (uae_u16 v, int num)
 {
 }
-static __inline__ void SPRxPOS_1 (uae_u16 v, int num)
+static inline void SPRxPOS_1 (uae_u16 v, int num)
 {
 }
-static __inline__ void SPRxDATA_1 (uae_u16 v, int num)
+static inline void SPRxDATA_1 (uae_u16 v, int num)
 {
 }
-static __inline__ void SPRxDATB_1 (uae_u16 v, int num)
+static inline void SPRxDATB_1 (uae_u16 v, int num)
 {
 }
 static void SPRxDATA (int hpos, uae_u16 v, int num) {}
@@ -722,7 +713,7 @@ static void JOYTEST (uae_u16 v)
  * Here starts the copper code. Can you believe it used to be worse?
  */
 
-static __inline__ void copper_adjust_diw (struct copper *cst)
+static inline void copper_adjust_diw (struct copper *cst)
 {
     if (cst->vdiw == DIW_waiting_start && vpos == plffirstline)
 	cst->vdiw = DIW_waiting_stop;
@@ -748,13 +739,13 @@ static unsigned int waitmasktab[256];
 
 #define COP_OFFSET 4
 
-static __inline__ int copper_in_playfield (enum diw_states diw, int hpos)
+static inline int copper_in_playfield (enum diw_states diw, int hpos)
 {
     hpos -= COP_OFFSET;
     return diw == DIW_waiting_stop && hpos >= plfstrt && hpos < plfstrt + plflinelen;
 }
 
-static __inline__ int copper_cant_read (enum diw_states diw, int hpos, int planes)
+static inline int copper_cant_read (enum diw_states diw, int hpos, int planes)
 {
     int t;
 
@@ -947,7 +938,7 @@ static void update_copper_1 (int until_hpos)
     cop_state.vpos = c_vpos;
 }
 
-static __inline__ void update_copper (int until_hpos)
+static inline void update_copper (int until_hpos)
 {
     if (cop_state.vpos > vpos
 	|| cop_state.hpos > until_hpos
@@ -1191,16 +1182,8 @@ static void adjust_array_sizes (void)
 
 static void vsync_handler (void)
 {
-    if (currprefs.m68k_speed == -1) {
-	frame_time_t curr_time = read_processor_time ();
-	vsyncmintime += vsynctime;
-	/* @@@ Mathias? How do you think we should do this? */
-	/* If we are too far behind, or we just did a reset, adjust the
-	 * needed time. */
-	if ((long int)(curr_time - vsyncmintime) > 0 || rpt_did_reset)
-	    vsyncmintime = curr_time + vsynctime;
+    if (currprefs.m68k_speed == -1)
 	rpt_did_reset = 0;
-    }
 
     INTREQ (0x8020);
     if (bplcon0 & 4)
@@ -1247,47 +1230,59 @@ static void vsync_handler (void)
     if (timehack_alive > 0)
 	timehack_alive--;
     CIA_vsync_handler();
-
-    uade_vsync_handler();
 }
 
 static void hsync_handler (void)
 {
-  eventtab[ev_hsync].evtime += cycles - eventtab[ev_hsync].oldcycles;
-  eventtab[ev_hsync].oldcycles = cycles;
-  CIA_hsync_handler();
-  
-  if (currprefs.produce_sound > 0) {
     int nr;
-    
+
+    eventtab[ev_hsync].evtime += cycles - eventtab[ev_hsync].oldcycles;
+    eventtab[ev_hsync].oldcycles = cycles;
+
+    CIA_hsync_handler();
+  
     update_audio ();
     
     /* Sound data is fetched at the beginning of each line */
     for (nr = 0; nr < 4; nr++) {
-      struct audio_channel_data *cdp = audio_channel + nr;
-      
-      if (cdp->data_written == 2) {
-	cdp->data_written = 0;
-	cdp->nextdat = chipmem_bank.wget(cdp->pt);
-	cdp->pt += 2;
-	if (cdp->state == 2 || cdp->state == 3) {
-	  if (cdp->wlen == 1) {
-	    cdp->pt = cdp->lc;
-	    cdp->wlen = cdp->len;
-	    cdp->intreq2 = 1;
-	  } else
-	    cdp->wlen--;
+	struct audio_channel_data *cdp = audio_channel + nr;
+
+	if (cdp->data_written == 2) {
+	    cdp->data_written = 0;
+
+#if AUDIO_DEBUG	   
+	    if (cdp->state != 0 && cdp->pt >= cdp->ptend) {
+		fprintf(stderr, "Audio DMA fetch overrun on channel %d: %.8x/%.8x\n", nr, cdp->pt, cdp->ptend);
+	    }
+#endif
+
+	    cdp->nextdat = chipmem_bank.wget(cdp->pt);
+
+	    cdp->nextdatpt = cdp->pt;
+	    cdp->nextdatptend = cdp->ptend;
+
+	    if (cdp->wlen != 1)
+		cdp->pt += 2;
+
+	    if (cdp->state == 2 || cdp->state == 3) {
+		if (cdp->wlen == 1) {
+		    cdp->pt = cdp->lc;
+		    cdp->ptend = cdp->lc + 2 * (cdp->len ? cdp->len : 65536);
+		    cdp->wlen = cdp->len;
+		    cdp->intreq2 = 1;
+		} else {
+		    cdp->wlen = (cdp->wlen - 1) & 0xFFFF;
+		}
+	    }
 	}
-      }
     }
-  }
   
-  if (++vpos == (maxvpos + (lof != 0))) {
-    vpos = 0;
-    vsync_handler();
-  }
+    if (++vpos == (maxvpos + (lof != 0))) {
+	vpos = 0;
+	vsync_handler();
+    }
   
-  is_lastline = vpos + 1 == maxvpos + (lof != 0) && currprefs.m68k_speed == -1 && ! rpt_did_reset;
+    is_lastline = vpos + 1 == maxvpos + (lof != 0) && currprefs.m68k_speed == -1 && ! rpt_did_reset;
 }
 
 static void init_eventtab (void)
@@ -1305,10 +1300,6 @@ static void init_eventtab (void)
     eventtab[ev_hsync].evtime = maxhpos + cycles;
     eventtab[ev_hsync].active = 1;
 
-    eventtab[ev_blitter].active = 0;
-    eventtab[ev_diskblk].active = 0;
-    eventtab[ev_diskindex].active = 0;
-
     events_schedule ();
 }
 
@@ -1361,8 +1352,8 @@ void customreset (void)
 
 void dumpcustom (void)
 {
-    write_log ("DMACON: %x INTENA: %x INTREQ: %x VPOS: %x HPOS: %x\n", DMACONR(),
-	       (unsigned int)intena, (unsigned int)intreq, (unsigned int)vpos, (unsigned int)current_hpos());
+    write_log ("DMACON: %x INTENA: %x INTREQ: %x VPOS: %x HPOS: %x CYCLES: %ld\n", DMACONR(),
+	       (unsigned int)intena, (unsigned int)intreq, (unsigned int)vpos, (unsigned int)current_hpos(), cycles);
     write_log ("COP1LC: %08lx, COP2LC: %08lx\n", (unsigned long)cop1lc, (unsigned long)cop2lc);
     if (timeframes) {
 	write_log ("Average frame time: %d ms [frames: %d time: %d]\n",
@@ -1370,8 +1361,6 @@ void dumpcustom (void)
 	if (total_skipped)
 	    write_log ("Skipped frames: %d\n", total_skipped);
     }
-    dump_audio_bench ();
-    /*for (i=0; i<256; i++) if (blitcount[i]) fprintf (stderr, "minterm %x = %d\n",i,blitcount[i]);  blitter debug */
 }
 
 int intlev (void)
@@ -1428,7 +1417,7 @@ addrbank custom_bank = {
     default_xlate, default_check
 };
 
-uae_u32 REGPARAM2 custom_wget (uaecptr addr)
+static uae_u32 REGPARAM2 custom_wget (uaecptr addr)
 {
     switch (addr & 0x1FE) {
      case 0x002: return DMACONR();
@@ -1455,17 +1444,17 @@ uae_u32 REGPARAM2 custom_wget (uaecptr addr)
     }
 }
 
-uae_u32 REGPARAM2 custom_bget (uaecptr addr)
+static uae_u32 REGPARAM2 custom_bget (uaecptr addr)
 {
     return custom_wget(addr & 0xfffe) >> (addr & 1 ? 0 : 8);
 }
 
-uae_u32 REGPARAM2 custom_lget (uaecptr addr)
+static uae_u32 REGPARAM2 custom_lget (uaecptr addr)
 {
     return ((uae_u32)custom_wget(addr & 0xfffe) << 16) | custom_wget((addr+2) & 0xfffe);
 }
 
-void REGPARAM2 custom_wput_1 (int hpos, uaecptr addr, uae_u32 value)
+static void REGPARAM2 custom_wput_1 (int hpos, uaecptr addr, uae_u32 value)
 {
     addr &= 0x1FE;
     switch (addr) {
@@ -1633,14 +1622,14 @@ void REGPARAM2 custom_wput_1 (int hpos, uaecptr addr, uae_u32 value)
     }
 }
 
-void REGPARAM2 custom_wput (uaecptr addr, uae_u32 value)
+static void REGPARAM2 custom_wput (uaecptr addr, uae_u32 value)
 {
     int hpos = current_hpos ();
     update_copper (hpos);
     custom_wput_1 (hpos, addr, value);
 }
 
-void REGPARAM2 custom_bput (uaecptr addr, uae_u32 value)
+static void REGPARAM2 custom_bput (uaecptr addr, uae_u32 value)
 {
     static int warned = 0;
     /* Is this correct now? (There are people who bput things to the upper byte of AUDxVOL). */
@@ -1649,12 +1638,12 @@ void REGPARAM2 custom_bput (uaecptr addr, uae_u32 value)
     //    addr=(uaecptr) (((char*) addr)-1);
     custom_wput(addr, rval);
     if (!warned) {
-	write_log ("Byte put to custom register.\n"), warned++;
-	fprintf(stderr,"0x%x to $%x\n",rval,addr);
+        warned++;
+	fprintf(stderr, "uade: Byte put to custom register (0x%x to $%x)\n", rval, addr);
     }
 }
 
-void REGPARAM2 custom_lput(uaecptr addr, uae_u32 value)
+static void REGPARAM2 custom_lput(uaecptr addr, uae_u32 value)
 {
     custom_wput(addr & 0xfffe, value >> 16);
     custom_wput((addr+2) & 0xfffe, (uae_u16)value);
