@@ -20,7 +20,6 @@
 #include "sysdeps.h"
 #include <ctype.h>
 
-#include "config.h"
 #include "options.h"
 #include "readcpu.h"
 
@@ -135,7 +134,7 @@ static const char *bit_mask (int size)
      case sz_long: return "0xffffffff";
      default: abort ();
     }
-    return 0;
+    return NULL;
 }
 
 static const char *gen_nextilong (void)
@@ -2311,7 +2310,6 @@ static void generate_includes (FILE * f)
 {
     fprintf (f, "#include \"sysconfig.h\"\n");
     fprintf (f, "#include \"sysdeps.h\"\n");
-    fprintf (f, "#include \"config.h\"\n");
     fprintf (f, "#include \"options.h\"\n");
     fprintf (f, "#include \"memory.h\"\n");
     fprintf (f, "#include \"custom.h\"\n");
